@@ -24,6 +24,8 @@
 ## Export: control.family
 ## Export: control.fixed
 ## Export: control.inla
+## Export: control.vb
+## Export: control.correct
 ## Export: control.predictor
 ## Export: control.results
 ## Export: control.mode
@@ -521,17 +523,14 @@
         ##:ARGUMENT: stupid.search.factor Numerical Factor (>=1) to increase the step-length with after each new interation. (default 1.05)
         stupid.search.factor = 1.05,
         
-        ##:ARGUMENT: correct Logical Add correction for the Laplace approximation. (default \code{FALSE})
-        correct = FALSE,
+        ##:ARGUMENT: control.vb List of arguments for various VB corrections. \code{enable} Logical Use this feature? \code{strategy} Charactor What to correct, one of "mean", "more.to.come.later...". \code{verbose} Logical Be verbose or not. \code{refinement} Integer Number of extra refinement iterations. \code{max.correct} Numerical Bound the allowed correction (\code{strategy="mean"}: \code{|diff.mean/stdev| < max.correct})
+        control.vb = list(enable = FALSE, strategy = "mean", verbose = TRUE, refinement = 0, max.correct = 1.0),
 
-        ##:ARGUMENT: correct.factor Numerical Factor used in adjusting the correction factor (default=10) if correct=TRUE
-        correct.factor = 10.0,
+        ##:ARGUMENT: control.correct List of control arguments for correction for the Laplace approximation: \code{enable} Logical Use this feature? \code{factor} Numerical Factor used in adjusting the correction factor (default=10) if \code{correct=TRUE}. \code{strategy}  Character The strategy used to compute the correction; one of 'simplified.laplace' (default) or 'laplace'. \code{verbose}  Logical Be verbose when computing the correction? (default \code{FALSE})
+        control.correct = list(enable = FALSE, factor = 10.0, strategy = "simplified.laplace", verbose = FALSE)
 
-        ##:ARGUMENT: correct.strategy  Character The strategy used to compute the correction; one of 'simplified.laplace' (default) or 'laplace'
-        correct.strategy = "simplified.laplace", 
-
-        ##:ARGUMENT: correct.verbose  Logical Be verbose when computing the correction? (default \code{FALSE})
-        correct.verbose = FALSE)
+        )
+        
  
     ##:SEEALSO: inla
 
@@ -761,6 +760,8 @@ control.compute = inla.make.completion.function(names(inla.set.control.compute.d
 control.family = inla.make.completion.function(names(inla.set.control.family.default()))
 control.fixed = inla.make.completion.function(names(inla.set.control.fixed.default()))
 control.inla = inla.make.completion.function(names(inla.set.control.inla.default()))
+control.vb = inla.make.completion.function(names(inla.set.control.inla.default()$control.vb))
+control.correct = inla.make.completion.function(names(inla.set.control.inla.default()$control.correct))
 control.predictor = inla.make.completion.function(names(inla.set.control.predictor.default()))
 control.results = inla.make.completion.function(names(inla.set.control.results.default()))
 control.mode = inla.make.completion.function(names(inla.set.control.mode.default()))
