@@ -49,11 +49,11 @@
                                    "date",
                                    "bdate"))
 {
-    rinla.hgid =  inla.trim("Version_20.05.12")
-    inla.hgid  =  inla.trim("Version_20.05.12")
-    date       =  inla.trim("Thu May 14 14:27:30 +03 2020")
-    bdate      =  inla.trim("202005141427")
-    version      =  inla.trim("20.05.12")
+    rinla.hgid =  inla.trim("Version_20.06.29")
+    inla.hgid  =  inla.trim("Version_20.06.29")
+    date       =  inla.trim("Mon 29 Jun 2020 02:19:21 PM +03")
+    bdate      =  inla.trim("202006291419")
+    version      =  inla.trim("20.06.29")
     what = match.arg(what)
 
     if (what %in% c("default", "info")) {
